#!/usr/local/bin/perl -w
#
# local_normal_local_global_wrapper.pl
#
# $Id: local_normal_local_global_wrapper.pl,v 1.2 2005/02/07 15:50:47 cjp Exp cjp $
#
# Wrapper for local normalisation script,
#   which uses a default gene list file.
#
# This version has extra options to change.
#
# The relevant pieces of code to change for your local set-up
#   are underlined with dashes (---).
#

use strict;

# Change the next line to the location of your script and gene list file.
use constant DEF_DIR => 'S:\Normalisation\\';
# Code to change:        ------------------     N.B., format ends with \\'

# Change the next line to what your default gene list file is called.
use constant DEF_GENE_LIST => 'gene_list.txt';
# Code to change:              -------------


MAIN: {

  # Set up command line.

  my $cmd =
    DEF_DIR . 'local_normal.pl' .   # Script location.
    ' --genefile ' . DEF_DIR . DEF_GENE_LIST .  # Gene list file.
    ' --file        "*.gpr"'  . # File(s) to be normalised.
    ' --filetext    local_global' . # String to be added to output files.
    ' --extgene     TRUE'     . # Use external gene list from separate file;
                                #   (default is gene_list.txt in same directory as script).
                                #   If false, use gene list made from input data file.
    ' --window      16'       . # Size of normalisation window (default is 16).
    ' --maxwin      24'       . # Maximum size of normalisation window (default is 24).
    ' --blocksize   400'      . # Size of normalisation block when using experimental spots
                                #   (default is 400).
    ' --blockstart  600'      . # Initial size of normalisation block when using
                                #   experimental spots (default is 600).
                                #   This is used to account for absent spots
                                #   in the initial square used.
    ' --spblocksize 20'       . # Size of normalisation block when using spikes
                                #   (default is 20).
    ' --spblockst   30'       . # Initial size of normalisation block when using spikes
                                #   (default is 30).
                                #   This is used to account for absent spots
                                #   in the initial square used.
    ' --round1      all-non-cont' . # Normalisation performed in first round with experimental
                                    #   spots; either: all-non-cont, none or not-using.
    ' --round2      global'   . # Normalisation performed in final round with spikes;
                                #   either: local, global, none or not-using.
    ' --bgcut       TRUE'     . # Use background SD cut-offs (default is true).
    ' --upperbg     95'       . # Upper cut-off for background SD (default is 95).
    ' --lowerbg     50'       . # Lower cut-off for background SD (default is 50).
    ' --diamcut     0'        . # Use/set spot diameter cut-off (default is 100);
                                #   default is not to use this cut-off.
    ' --spotnorm    TRUE'     . # Calculate normalised data for all good spots.
    ' --genenorm    TRUE'     . # Calculate normalised data for all good genes.
    ' --genestats   TRUE'     . # Prints extra information about normalised data
                                #   for all good genes (default is false).
    ' --alldata     TRUE'     . # Prints all data for all spots plus normalised data.
    ' --log         TRUE'     . # Print log information to a file (default is true);
                                #   otherwise print it to stderr.
    ' --info        FALSE';     # Print header information to a file.

  # Run the script.

  system $cmd;

  exit 0;

}
